@@ -1,18 +1,20 @@
 from .user import User
 from .base import Base
 from .utils import Utils
-from .assignment import Assignment
-from .attendance import Attendance
-from .cohort import Cohort
-from .session import Session
-from .cohort_group import CohortGroup
-from .cohort_member import CohortMember
 from .course import Course
-from .lead import Lead
-from .progress_score import ProgressScore
+from .cohort import Cohort
+from .cohort_group import CohortGroup
 from .student import Student
+from .cohort_member import CohortMember
+from .session import Session
+from .attendance import Attendance
+from .assignment import Assignment
 from .submission import Submission
 from .submission_grade import SubmissionGrade
+from .progress_score import ProgressScore
+from .lead import Lead
+from .template_notebook import TemplateNotebook
+from .assignment_report import assignment_report
 
 
 
